==> bzflag_1.10.6.20040516.tar.gz: bzflag-1.10.6.20040516/src/geometry/models/tank/medium_barrel.cxx <==
/* bzflag
 * Copyright (c) 1993 - 2004 Tim Riker
 *
 * This package is free software;  you can redistribute it and/or
 * modify it under the terms of the license found in the file
 * named COPYING that should have accompanied this file.
 *
 * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "TankSceneNode.h"

#define	doVertex3f	doVertex3f
#define	doNormal3f	doNormal3f

void buildMedBarrel ( void )
{
      glShadeModel(GL_SMOOTH);
      glBegin(GL_TRIANGLE_STRIP);
	doNormal3f(0.0f, -1.0f, 0.0f);
	doVertex3f(1.570f, -0.18f, 1.530f);
	doVertex3f(4.940f, -0.126f, 1.530f);
	doNormal3f(0.0f, 0.0f, 1.0f);
	doVertex3f(1.570f, 0.0f, 1.710f);
	doVertex3f(4.940f, 0.0f, 1.660f);
	doNormal3f(0.0f, 1.0f, 0.0f);
	doVertex3f(1.570f, 0.18f, 1.530f);
	doVertex3f(4.940f, 0.126f, 1.530f);
	doNormal3f(0.0f, 0.0f, -1.0f);
	doVertex3f(1.570f, 0.0f, 1.350f);
	doVertex3f(4.940f, 0.0f, 1.410f);
	doNormal3f(0.0f, -1.0f, 0.0f);
	doVertex3f(1.570f, -0.18f, 1.530f);
	doVertex3f(4.940f, -0.126f, 1.530f);
      glEnd();
      glShadeModel(GL_FLAT);
      glBegin(GL_TRIANGLE_FAN);
	doNormal3f(1.000000f, 0.000000f, 0.000000f);
	doVertex3f(4.940f, 0.0f, 1.410f);
	doVertex3f(4.940f, 0.126f, 1.530f);
	doVertex3f(4.940f, 0.0f, 1.660f);
	doVertex3f(4.940f, -0.126f, 1.530f);
      glEnd();
}
/*
 * Local Variables: ***
 * mode:C ***
 * tab-width: 8 ***
 * c-basic-offset: 2 ***
 * indent-tabs-mode: t ***
 * End: ***
 * ex: shiftwidth=2 tabstop=8
 */

==> bzflag_2.0.2.20050318.tar.gz: bzflag-2.0.2.20050318/src/geometry/models/tank/medium_barrel.cxx <==
/* bzflag
 * Copyright (c) 1993 - 2005 Tim Riker
 *
 * This package is free software;  you can redistribute it and/or
 * modify it under the terms of the license found in the file
 * named COPYING that should have accompanied this file.
 *
 * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "TankGeometryMgr.h"
using namespace TankGeometryUtils;

void TankGeometryUtils::buildMedBarrel ( void )
{
      glShadeModel(GL_SMOOTH);
      glBegin(GL_TRIANGLE_STRIP);
	doNormal3f(0.0f, -1.0f, 0.0f);
	doVertex3f(1.570f, -0.18f, 1.530f);
	doVertex3f(4.940f, -0.126f, 1.530f);
	doNormal3f(0.0f, 0.0f, 1.0f);
	doVertex3f(1.570f, 0.0f, 1.710f);
	doVertex3f(4.940f, 0.0f, 1.660f);
	doNormal3f(0.0f, 1.0f, 0.0f);
	doVertex3f(1.570f, 0.18f, 1.530f);
	doVertex3f(4.940f, 0.126f, 1.530f);
	doNormal3f(0.0f, 0.0f, -1.0f);
	doVertex3f(1.570f, 0.0f, 1.350f);
	doVertex3f(4.940f, 0.0f, 1.410f);
	doNormal3f(0.0f, -1.0f, 0.0f);
	doVertex3f(1.570f, -0.18f, 1.530f);
	doVertex3f(4.940f, -0.126f, 1.530f);
      glEnd();
      glShadeModel(GL_FLAT);
      glBegin(GL_TRIANGLE_FAN);
	doNormal3f(1.000000f, 0.000000f, 0.000000f);
	doVertex3f(4.940f, 0.0f, 1.410f);
	doVertex3f(4.940f, 0.126f, 1.530f);
	doVertex3f(4.940f, 0.0f, 1.660f);
	doVertex3f(4.940f, -0.126f, 1.530f);
      glEnd();
}
/*
 * Local Variables: ***
 * mode:C ***
 * tab-width: 8 ***
 * c-basic-offset: 2 ***
 * indent-tabs-mode: t ***
 * End: ***
 * ex: shiftwidth=2 tabstop=8
 */
